==> castor-jdo-1.2-sources.jar: org/exolab/castor/jdo/QueryResults.java <==
/**
 * Redistribution and use of this software and associated documentation
 * ("Software"), with or without modification, are permitted provided
 * that the following conditions are met:
 *
 * 1. Redistributions of source code must retain copyright
 *    statements and notices.  Redistributions must also contain a
 *    copy of this document.
 *
 * 2. Redistributions in binary form must reproduce the
 *    above copyright notice, this list of conditions and the
 *    following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 3. The name "Exolab" must not be used to endorse or promote
 *    products derived from this Software without prior written
 *    permission of Intalio, Inc.  For written permission,
 *    please contact info@exolab.org.
 *
 * 4. Products derived from this Software may not be called "Exolab"
 *    nor may "Exolab" appear in their names without prior written
 *    permission of Intalio, Inc. Exolab is a registered
 *    trademark of Intalio, Inc.
 *
 * 5. Due credit should be given to the Exolab Project
 *    (http://www.exolab.org/).
 *
 * THIS SOFTWARE IS PROVIDED BY INTALIO, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 * INTALIO, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Copyright 1999 (C) Intalio, Inc. All Rights Reserved.
 *
 * $Id: QueryResults.java 7091 2007-07-28 21:29:43Z rjoachim $
 */
package org.exolab.castor.jdo;

import java.util.Enumeration;
import java.util.NoSuchElementException;

/**
 * An iteration of the results of a query. This interface provides the
 * ability to move forward only in the result set and pick the next
 * result and close it.
 *
 * @author <a href="arkin@intalio.com">Assaf Arkin</a>
 * @version $Revision: 7091 $ $Date: 2004-05-03 16:05:30 -0600 (Mon, 03 May 2004) $
 */
public interface QueryResults extends Enumeration {
    /**
     * Returns true if there are any more results in the result set.
     * If an error occured reading the last result, an exception will
     * be thrown and the result set cannot be used further.
     *
     * @return True if there are any more results in the result set
     * @throws PersistenceException An error with the persistence engine
     */
    boolean hasMore() throws PersistenceException;

    /**
     * Returns the next result in the result set. If there are no
     * more results (a previous cal to {@link #hasMore} returns
     * false) this method will throw an exceptin. If an error
     * occured reading the last result, an exception will be
     * thrown and the result set cannot be used further.
     *
     * @return The next result in the result set
     * @throws PersistenceException An error with the persistence
     *  engine
     * @throws NoSuchElementException There are no more results in
     *  the result set
     */
    Object next() throws PersistenceException, NoSuchElementException;

    /**
     * Closes the result set and releases all resources held by it.
     */
    void close();

    /**
     * moves the result of the query to the absolute position in the
     * resultset.
     * 
     * @param row The row to move to
     * @return ???
     * @throws PersistenceException A persistence error occured
     */
    boolean absolute(int row) throws PersistenceException;

    /**
     * Finds the size of the resulting resultset from the query.
     * 
     * @return Size of the resulting result set.
     * @throws PersistenceException A persistence error occured
     */
    int size() throws PersistenceException;
}

==> castor-jdo-1.3.3-rc1-sources.jar: org/exolab/castor/jdo/QueryResults.java <==
/**
 * Redistribution and use of this software and associated documentation
 * ("Software"), with or without modification, are permitted provided
 * that the following conditions are met:
 *
 * 1. Redistributions of source code must retain copyright
 *    statements and notices.  Redistributions must also contain a
 *    copy of this document.
 *
 * 2. Redistributions in binary form must reproduce the
 *    above copyright notice, this list of conditions and the
 *    following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 3. The name "Exolab" must not be used to endorse or promote
 *    products derived from this Software without prior written
 *    permission of Intalio, Inc.  For written permission,
 *    please contact info@exolab.org.
 *
 * 4. Products derived from this Software may not be called "Exolab"
 *    nor may "Exolab" appear in their names without prior written
 *    permission of Intalio, Inc. Exolab is a registered
 *    trademark of Intalio, Inc.
 *
 * 5. Due credit should be given to the Exolab Project
 *    (http://www.exolab.org/).
 *
 * THIS SOFTWARE IS PROVIDED BY INTALIO, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 * INTALIO, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Copyright 1999 (C) Intalio, Inc. All Rights Reserved.
 *
 * $Id: QueryResults.java 8994 2011-08-01 23:40:59Z rjoachim $
 */
package org.exolab.castor.jdo;

import java.util.Enumeration;
import java.util.NoSuchElementException;

/**
 * An iteration of the results of a query. This interface provides the
 * ability to move forward only in the result set and pick the next
 * result and close it.
 *
 * @author <a href="arkin@intalio.com">Assaf Arkin</a>
 * @version $Revision: 8994 $ $Date: 2011-08-02 01:40:59 +0200 (Di, 02 Aug 2011) $
 */
public interface QueryResults extends Enumeration<Object> {
    /**
     * Returns true if there are any more results in the result set.
     * If an error occured reading the last result, an exception will
     * be thrown and the result set cannot be used further.
     *
     * @return True if there are any more results in the result set
     * @throws PersistenceException An error with the persistence engine
     */
    boolean hasMore() throws PersistenceException;

    /**
     * Returns the next result in the result set. If there are no
     * more results (a previous cal to {@link #hasMore} returns
     * false) this method will throw an exceptin. If an error
     * occured reading the last result, an exception will be
     * thrown and the result set cannot be used further.
     *
     * @return The next result in the result set
     * @throws PersistenceException An error with the persistence
     *  engine
     * @throws NoSuchElementException There are no more results in
     *  the result set
     */
    Object next() throws PersistenceException, NoSuchElementException;

    /**
     * Closes the result set and releases all resources held by it.
     */
    void close();

    /**
     * moves the result of the query to the absolute position in the
     * resultset.
     * 
     * @param row The row to move to
     * @return ???
     * @throws PersistenceException A persistence error occured
     */
    boolean absolute(int row) throws PersistenceException;

    /**
     * Finds the size of the resulting resultset from the query.
     * 
     * @return Size of the resulting result set.
     * @throws PersistenceException A persistence error occured
     */
    int size() throws PersistenceException;
}
